@@ -1,3 +1,7 @@
+"""
+Provides access to default files and variables
+"""
+
 # Gleaned from
 # Copyright © 2007 Francisco Javier de la Peña
 # file of EELSLab.
@@ -11,8 +15,8 @@ from pyTEMlib.config_dir import config_path, os_name, data_path
 defaults_file = os.path.join(config_path, 'TEMlibrc')
 bool_keys = ['fs_state', 'synchronize_cl_with_ll', 'plot_on_load']
 str_keys = ['microscope', 'GOS_dir', 'fitter', 'file_format']
-float_keys = ['fs_emax', 'preedge_safe_window_width', 
-'knots_factor', 'min_distance_between_edges_for_fine_structure' ]
+float_keys = ['fs_emax', 'preedge_safe_window_width',
+              'knots_factor', 'min_distance_between_edges_for_fine_structure']
 
 Gos_file = os.path.join(data_path, 'GOS.tar.gz')
 f = open(defaults_file, 'r')
@@ -20,14 +24,14 @@ defaults_dict = {}
 for line in f:
     if line[0] != "#":
         line_list = line.split()
-        if line_list != []:
+        if line_list:
             if line_list[0] in float_keys:
                 key, value = line_list
                 defaults_dict[key] = float(value)
             elif line_list[0] in str_keys:
-                key =  line_list[0]
+                key = line_list[0]
                 
-                for i in range(1,len(line_list)):
+                for i in range(1, len(line_list)):
                     if i > 1:
                         value = value+' '+line_list[i]
                     else:
@@ -45,11 +49,9 @@ if defaults_dict['GOS_dir'] == 'None':
         # location in windows
         program_files = os.environ['PROGRAMFILES']
         
-        gos = '\Gatan\EELS Reference Data\H-S GOS Table\ ' 
-        gos_path ='C:\ProgramData\Gatan\EELS Reference Data\H-S GOS Tables'
+        gos = '\\Gatan\\EELS Reference Data\\H-S GOS Table\\'
+        gos_path = 'C:\\ProgramData\\Gatan\\EELS Reference Data\\H-S GOS Tables'
 
-        
-        
         # Check whether it is in the (x86) Program folder of windows 7
         if os.path.isdir(gos_path) is False:
             program_files += ' (x86)'
@@ -61,16 +63,18 @@ if defaults_dict['GOS_dir'] == 'None':
         gos_path = os.path.join(config_path, 'GOS')
     
     if os.path.isdir(gos_path) is False and os.path.isfile(Gos_file) is True:
-        #messages.alert("Installing the GOS files in: %s" % gos_path) 
+        # messages.alert("Installing the GOS files in: %s" % gos_path)
         tar = tarfile.open(Gos_file)
         os.mkdir(gos_path)
         tar.extractall(gos_path)
     if os.path.isdir(gos_path):
         defaults_dict['GOS_dir'] = gos_path
         
+
 class Defaults:
     pass
 
+
 defaults = Defaults()
 defaults.__dict__ = defaults_dict
 
@@ -80,7 +84,7 @@ tutorial_file = os.path.join(data_path, 'tutorial.tar.gz')
 tutorial_directory = os.path.expanduser('~/eelslab_tutorial')
 if os.path.isfile(tutorial_file) is True:
     if os.path.isdir(tutorial_directory) is False:
-        #messages.alert("Installing the tutorial in: %s" % tutorial_directory) 
+        # messages.alert("Installing the tutorial in: %s" % tutorial_directory)
         tar = tarfile.open(tutorial_file)
         os.mkdir(tutorial_directory)
         tar.extractall(tutorial_directory)
