@@ -1,3 +1,6 @@
+"""
+EELS_Dialog for interactive_eels
+"""
 from PyQt5 import QtCore,  QtWidgets
 from pyTEMlib import eels_dlg
 
@@ -20,6 +23,16 @@ class EELSDialog(QtWidgets.QDialog):
     def __init__(self, dataset=None):
         super().__init__(None, QtCore.Qt.WindowStaysOnTopHint)
         # Create an instance of the GUI
+        if dataset is None:
+            # make a dummy dataset
+            dataset = ft.make_dummy_dataset(sidpy.DataTypes.SPECTRUM)
+        if not isinstance(dataset, sidpy.Dataset):
+            raise TypeError('dataset has to be a sidpy dataset')
+        self.spec_dim = ft.get_dimensions_by_type('spectral', dataset)
+        if len(self.spec_dim) != 1:
+            raise TypeError('We need exactly one SPECTRAL dimension')
+        self.spec_dim = self.spec_dim[0]
+
         self.ui = eels_dlg.UiDialog(self)
         # Run the .setup_ui() method to show the GUI
         # self.ui.setup_ui(self)
@@ -34,13 +47,6 @@ class EELSDialog(QtWidgets.QDialog):
         self.show_regions = False
         self.show()
 
-        if dataset is None:
-            # make a dummy dataset
-            dataset = ft.make_dummy_dataset(sidpy.DataTypes.SPECTRUM)
-
-        if not isinstance(dataset, sidpy.Dataset):
-            raise TypeError('dataset has to be a sidpy dataset')
-
         self.set_dataset(dataset)
         # TODO: set elements does not work correctly for periodic table
         # selected_edges = eels.find_edges(dataset, sensitivity=3)
@@ -63,7 +69,6 @@ class EELSDialog(QtWidgets.QDialog):
         elif hasattr(self.dataset.view, 'axis'):
             self.axis = self.dataset.view.axis
         self.figure = self.axis.figure
-
         self.cid = self.figure.canvas.mpl_connect('draw_event', self.plot)
 
         self.plot()
@@ -85,8 +90,8 @@ class EELSDialog(QtWidgets.QDialog):
 
         self.spec_dim = spec_dim
         self.energy_scale = dataset._axes[spec_dim].values
-
         self.ui.edit2.setText(f"{self.energy_scale[-2]:.3f}")
+
         if 'fit_area' not in self.edges:
             self.edges['fit_area'] = {}
         if 'fit_start' not in self.edges['fit_area']:
@@ -250,7 +255,7 @@ class EELSDialog(QtWidgets.QDialog):
     def set_elements(self, selected_elements):
 
         edge_list = self.ui.list3
-        index = edge_list.currentIndex()
+        index = 0  # edge_list.currentIndex()
 
         for elem in selected_elements:
             if self.update_element(elem):
