@@ -1,3 +1,7 @@
+# -*- coding: utf-8 -*-
+"""
+File Tools for pyTEMlib
+"""
 ##################################
 #
 # 2018 01 31 Included Nion Swift files to be opened
@@ -29,12 +33,14 @@ import pyNSID
 import ipywidgets as widgets
 from IPython.display import display
 
-from .sidpy_tools import *
-# import sys
-# sys.path.insert(0, "../../sidpy/")
+import pyTEMlib.sidpy_tools
+import sys
+sys.path.insert(0, "../../sidpy/")
 import sidpy
 
+import sidpy.hdf.prov_utils as hdf_utils
 
+ChooseDataset = pyTEMlib.sidpy_tools.ChooseDataset
 Dimension = sidpy.Dimension
 nest_dict = sidpy.base.dict_utils.nest_dict
 
@@ -46,6 +52,9 @@ __version__ = '10.30.2020'
 
 
 def flatten_dict(d, parent_key='', sep='-'):
+    """
+    should be in sidpy
+    """
     items = []
     for k, v in d.items():
         if sep in k:
@@ -67,9 +76,9 @@ def flatten_dict(d, parent_key='', sep='-'):
     return dict(items)
 
 
-####
+#
 #  General Open and Save Methods
-####
+#
 
 
 def get_qt_app():
@@ -90,6 +99,9 @@ def get_qt_app():
 
 
 def get_last_path():
+    """
+    Get last path used in pyTEMlib
+    """
     try:
         fp = open(config_path + '\\path.txt', 'r')
         path = fp.read()
@@ -103,6 +115,9 @@ def get_last_path():
 
 
 def save_path(filename):
+    """
+    save last path used in pyTEMlin
+    """
     if len(filename) > 1:
         fp = open(config_path + '\\path.txt', 'w')
         path, fname = os.path.split(filename)
@@ -114,6 +129,9 @@ def save_path(filename):
 
 
 def set_directory():
+    """
+    set directory to last used path in pyTEMlib
+    """
     path = get_last_path()
 
     try:
@@ -164,6 +182,7 @@ def savefile_dialog(initial_file='*.hf5', file_types=None):
 def openfile_dialog(file_types=None):  # , multiple_files=False):
     """
     Opens a File dialog which is used in open_file() function
+
     This function uses tkinter or pyQt5.
     The app of the Gui has to be running for QT so Tkinter is a safer bet.
     In jupyter notebooks use %gui Qt early in the notebook.
@@ -172,24 +191,15 @@ def openfile_dialog(file_types=None):  # , multiple_files=False):
     The file looks first for a path.txt file for the last directory you used.
 
     Parameters
-    ----------
-    file_types : string of the file type filter
-
-
+        file_types : string of the file type filter
     Returns
-    -------
-    filename : full filename with absolute path and extension as a string
-
+        filename : full filename with absolute path and extension as a string
     Examples
-    --------
-
-    >> import file_tools as ft
-    >>
-    >> filename = ft.openfile_dialog()
-    >>
-    >> print(filename)
-
-
+        >> import file_tools as ft
+        >>
+        >> filename = ft.openfile_dialog()
+        >>
+        >> print(filename)
     """
     # determine file types by extension
     if file_types is None:
@@ -213,9 +223,25 @@ def openfile_dialog(file_types=None):  # , multiple_files=False):
     return filename
 
 
+def read_h5_dataset(h5_group):
+    """
+    Reads a h5_dataset
+    """
+    if isinstance(h5_group, h5py.Group):
+        reader = NSIDReader(h5_group)
+        dataset = reader.read()[-1]
+    elif isinstance(h5_group, h5py.Dataset):
+        reader = NSIDReader(h5_group)
+        dataset = reader.read_h5py_dataset(h5_group)
+    else:
+        raise ValueError( 'Need a h5py Group to read a dataset')
+
+    return dataset
+
 def open_file(filename=None, save_file=False, h5_group=None):
     """
     Opens a file if the extension is .hf5, .dm3 or .dm4
+
     If no filename is provided the qt open_file windows opens
 
     Everything will be stored in a NSID style hf5 file.
@@ -293,6 +319,9 @@ def open_file(filename=None, save_file=False, h5_group=None):
 
 
 def get_h5_filename(fname):
+    """
+    Determine file name for nsid file
+    """
     path, filename = os.path.split(fname)
     basename, extension = os.path.splitext(filename)
     h5_file_name_original = os.path.join(path, basename + '.hf5')
@@ -316,6 +345,9 @@ def get_start_channel(h5_file):
 
 
 def get_main_channel(h5_file):
+    """
+    get name of directory in hdf5 file system
+    """
     current_channel = None
     if 'Measurement_000' in h5_file:
         if 'Measurement_000/Channel_000' in h5_file:
@@ -326,6 +358,7 @@ def get_main_channel(h5_file):
 def h5_tree(input):
     """
     Just a wrapper for the sidpy function print_tree,
+
     so that sidpy does not have to be loaded in notebook
     """
     if isinstance(input, sidpy.Dataset):
@@ -342,30 +375,65 @@ def h5_tree(input):
 
 
 def log_results(h5_group, dataset=None, attributes=None):
+    """
+    Log results in nsid style file
+    """
     if dataset is None:
-        log_group = sidpy.hdf.prov_utils.create_indexed_group(h5_group, 'Log_')
+        log_group = hdf_utils.create_indexed_group(h5_group, 'Log_')
     else:
         log_group = pyNSID.hdf_io.write_results(h5_group, dataset=dataset)
-        if hasattr(dataset, 'meta_data'):
-            metadata = sidpy.dict_utils.flatten_dict(dataset.meta_data)
-            metadata_group = log_group.create_group('meta_data')
-            for key, item in metadata.items():
-                metadata_group.attrs[key] = item
-            if 'analysis' in dataset.meta_data:
-                log_group['analysis'] = dataset.meta_data['analysis']
+        if 'analysis' in dataset.metadata:
+            if 'analysis' not in log_group:
+                log_group['analysis'] = dataset.metadata['analysis']
+            else:
+                log_group['analysis'][()] = dataset.metadata['analysis']
 
         dataset.h5_dataset = log_group[dataset.title.replace('-', '_')]
     if attributes is not None:
-        for key, item in attributes.items():
+        for key, item in flatten_dict(attributes).items():
             if key not in log_group:
                 log_group[key] = item
 
     return log_group
 
 
-###############################################
+###
+# Crystal Structure Read and Write
+###
+def h5_add_crystal_structure(h5_file, crystal_tags):
+    structure_group = hdf_utils.create_indexed_group(h5_file, 'Structure')
+
+    structure_group['unit_cell'] = np.squeeze(crystal_tags['unit_cell'])
+    structure_group['relative_positions'] = np.squeeze(crystal_tags['base'])
+    structure_group['title'] = str(crystal_tags['crystal_name'])
+    structure_group['_' + crystal_tags['crystal_name']] = str(crystal_tags['crystal_name'])
+    structure_group['elements'] = np.array(crystal_tags['elements'], dtype='S')
+    if 'zone_axis' in structure_group:
+        structure_group['zone_axis'] = np.array(crystal_tags['zone_axis'], dtype=float)
+    else:
+        structure_group['zone_axis'] = np.array([1., 0., 0.], dtype=float)
+    h5_file.flush()
+    return structure_group
+
+
+def h5_get_crystal_structure(structure_group):
+    crystal_tags = {'unit_cell': structure_group['unit_cell'][()], 'base': structure_group['relative_positions'][()],
+                    'crystal_name': structure_group['title'][()]}
+    if '2D' in structure_group:
+        crystal_tags['2D'] = structure_group['2D'][()]
+    elements = structure_group['elements'][()]
+    crystal_tags['elements'] = []
+    for e in elements:
+        crystal_tags['elements'].append(e.astype(str, copy=False))
+
+    if 'zone_axis' in structure_group:
+        crystal_tags['zone_axis'] = structure_group['zone_axis'][()]
+    return crystal_tags
+
+
+# ##############################################
 # Support old pyTEM file format
-###############################################
+# ##############################################
 
 def read_old_h5group(current_channel):
     """
@@ -436,9 +504,10 @@ def read_old_h5group(current_channel):
 def set_dimensions(dset, current_channel):
     """
     Attaches correct dimension from old pyTEMlib style.
+
     Input:
-    dset: sidpy Dataset
-    current_channel: hdf5 group
+        dset: sidpy Dataset
+        current_channel: hdf5 group
     """
     dim = 0
     if dset.data_type == sidpy.DataTypes.IMAGE_STACK:
