@@ -1,8 +1,13 @@
+"""
+InfoDialog for interactive_eels
+"""
+
 from PyQt5 import QtCore,  QtWidgets
 
 import numpy as np
 import sidpy
 from pyTEMlib import info_dlg
+import pyTEMlib.eels_tools as eels
 import pyTEMlib.interactive_eels as ieels
 from pyTEMlib.microscope import microscope
 
@@ -83,8 +88,13 @@ class InfoDialog(QtWidgets.QDialog):
                         'convergence_angle': 0.0, 'collection_angle': 0.0,
                         'acceleration_voltage': 100.0, 'binning': 1, 'conversion': 1.0,
                         'flux': 1.0, 'current': 1.0}
-        if 'experiment' not in self.dataset.metadata:
-            self.dataset.metadata['experiment'] = minimum_info
+
+        if 'DM' in self.dataset.original_metadata:
+            if 'experiment' not in self.dataset.metadata:
+                self.dataset.metadata['experiment'] = {}
+
+            self.dataset.metadata['experiment'].update(eels.read_dm3_eels_info(self.dataset.original_metadata))
+
         self.experiment = self.dataset.metadata['experiment']
 
         for key, item in minimum_info.items():
