@@ -1,4 +1,6 @@
-
+"""
+Interactive EELS provides dialogs for input
+"""
 import numpy as np
 
 from PyQt5 import QtWidgets, QtCore, QtGui
@@ -39,7 +41,6 @@ class PeriodicTableDialog(QtWidgets.QDialog):
     energy_scale: list or numpy array
         energy-scale of spectrum/spectra to determine likely edges
 
-
     Returns:
     list of strings: elements.
     Usage:
@@ -1080,135 +1081,6 @@ class ElementalEdges(object):
         self.ax.figure.canvas.mpl_disconnect(self.cid)
 
 
-class RegionSelector(object):
-    """
-        Selects fitting region and the regions that are excluded for each edge.
-
-        Select a region with a spanSelector and then type 'a' for all of the fitting region or a number for the 
-        edge you want to define the region excluded from the fit (solid state effects).
-
-        see Chapter4 'CH4-Working_with_X-Sections,ipynb' notebook
-
-    """
-
-    def __init__(self, ax):
-        self.ax = ax
-        self.regions = {}
-        self.rect = None
-        self.xmin = 0
-        self.xwidth = 0
-
-        self.span = SpanSelector(ax, self.onselect1, 'horizontal', useblit=True,
-                                 rectprops=dict(alpha=0.5, facecolor='red'), span_stays=True)
-        self.cid = ax.figure.canvas.mpl_connect('key_press_event', self.click)
-        self.draw = ax.figure.canvas.mpl_connect('draw_event', self.onresize)
-
-    def onselect1(self, xmin, xmax):
-        self.xmin = xmin
-        self.width = xmax - xmin
-
-    def onresize(self, event):
-        self.update()
-
-    def delete_region(self, key):
-        if key in self.regions:
-            if 'Rect' in self.regions[key]:
-                self.regions[key]['Rect'].remove()
-                self.regions[key]['Text'].remove()
-            del (self.regions[key])
-
-    def update(self):
-
-        y_min, y_max = self.ax.get_ylim()
-        for key in self.regions:
-            if 'Rect' in self.regions[key]:
-                self.regions[key]['Rect'].remove()
-                self.regions[key]['Text'].remove()
-
-            xmin = self.regions[key]['xmin']
-            width = self.regions[key]['width']
-            height = y_max - y_min
-            alpha = self.regions[key]['alpha']
-            color = self.regions[key]['color']
-            self.regions[key]['Rect'] = patches.Rectangle((xmin, y_min), width, height,
-                                                          edgecolor=color, alpha=alpha, facecolor=color)
-            self.ax.add_patch(self.regions[key]['Rect'])
-
-            self.regions[key]['Text'] = self.ax.text(xmin, y_max, self.regions[key]['text'], verticalalignment='top')
-
-    def click(self, event):
-        if str(event.key) in ['1', '2', '3', '4', '5', '6']:
-            key = str(event.key)
-            text = 'exclude \nedge ' + key
-            alpha = 0.5
-            color = 'red'
-        elif str(event.key) in ['a', 'A', 'b', 'B', 'f', 'F']:
-            key = '0'
-            color = 'blue'
-            alpha = 0.2
-            text = 'fit region'
-        else:
-            return
-
-        if key not in self.regions:
-            self.regions[key] = {}
-
-        self.regions[key]['xmin'] = self.xmin
-        self.regions[key]['width'] = self.width
-        self.regions[key]['color'] = color
-        self.regions[key]['alpha'] = alpha
-        self.regions[key]['text'] = text
-
-        self.update()
-
-    def set_regions(self, region, start_x, width):
-        if 'fit' in str(region):
-            key = '0'
-        if region in ['0', '1', '2', '3', '4', '5', '6']:
-            key = region
-        if region in [0, 1, 2, 3, 4, 5, 6]:
-            key = str(region)
-
-        if key not in self.regions:
-            self.regions[key] = {}
-            if key in ['1', '2', '3', '4', '5', '6']:
-                self.regions[key]['text'] = 'exclude \nedge ' + key
-                self.regions[key]['alpha'] = 0.5
-                self.regions[key]['color'] = 'red'
-            elif key == '0':
-                self.regions[key]['text'] = 'fit region'
-                self.regions[key]['alpha'] = 0.2
-                self.regions[key]['color'] = 'blue'
-
-        self.regions[key]['xmin'] = start_x
-        self.regions[key]['width'] = width
-
-        self.update()
-
-    def get_regions(self):
-        tags = {}
-        for key in self.regions:
-            if key == '0':
-                area = 'fit_area'
-            else:
-                area = key
-            tags[area] = {}
-            tags[area]['start_x'] = self.regions[key]['xmin']
-            tags[area]['width_x'] = self.regions[key]['width']
-
-        return tags
-
-    def disconnect(self):
-        for key in self.regions:
-            if 'Rect' in self.regions[key]:
-                self.regions[key]['Rect'].remove()
-                self.regions[key]['Text'].remove()
-        del self.span
-        self.ax.figure.canvas.mpl_disconnect(self.cid)
-        # self.ax.figure.canvas.mpl_disconnect(self.draw)
-        pass
-
-
 class EdgesatCursor(object):
     """
         Adds a Cursor to a plot, which plots all major (possible) ionization edges at
@@ -1303,222 +1175,3 @@ class EdgesatCursor(object):
 
         self.ax.figure.canvas.mpl_disconnect(self.cid)
         self.ax.figure.canvas.mpl_disconnect(self.mouse_cid)
-
-
-class ElementalEdges(object):
-    """
-        The necessary initialization parameter are:
-        ax: matplotlib axis
-
-
-        There is an optional parameter maximum_chemical_shift which allows to change
-        the energy range in which the edges are searched.
-
-        available functions:
-        - update(): updates the drawing of ionization edges
-        - set_edge(z) : changes atomic number and updates everything accordingly
-        - disconnect: makes everything invisible and stops drawing
-        - reconnect: undo of disconnect
-
-        usage:
-        >>  fig, ax = plt.subplots()
-        >>  ax.plot(energy_scale, spectrum)
-        >>  z= 42
-        >>  cursor = ElementalEdges(ax, z)
-
-
-        see Chapter4 'CH4-Working_with_X-Sections' notebook
-    """
-
-    def __init__(self, ax, z):
-        self.ax = ax
-        self.labels = None
-        self.lines = None
-        self.z = eels.get_z(z)
-        self.color = 'black'
-        self.x_sections = eels.get_x_sections()
-        self.cid = ax.figure.canvas.mpl_connect('draw_event', self.on_resize)
-        # self.update() is not necessary because of a drawing event is issued
-
-    def set_edge(self, z):
-        self.z = eels.get_z(z)
-        if self.cid is None:
-            self.cid = self.ax.figure.canvas.mpl_connect('draw_event', self.on_resize)
-        self.update()
-
-    def on_resize(self, event):
-        self.update()
-
-    def update(self):
-        if self.labels is not None:
-            for label in self.labels:
-                label.remove()
-        if self.lines is not None:
-            for line in self.lines:
-                line.remove()
-        self.labels = []
-        self.lines = []
-        x_min, x_max = self.ax.get_xlim()
-        y_min, y_max = self.ax.get_ylim()
-
-        element = str(self.z)
-        x_sections = self.x_sections
-        for key in all_edges:
-            if key in x_sections[element]:
-                if 'onset' in x_sections[element][key]:
-                    x = x_sections[element][key]['onset']
-                    if x_min < x < x_max:
-                        if key in first_close_edges:
-                            label2 = self.ax.text(x, y_max, f"{x_sections[element]['name']}-{key}",
-                                                  verticalalignment='top', rotation=0, color=self.color)
-                        else:
-                            label2 = self.ax.text(x, y_max, f"\n{x_sections[element]['name']}-{key}",
-                                                  verticalalignment='top', color=self.color)
-                        line2 = self.ax.axvline(x, ymin=0, ymax=1, color=self.color)
-
-                        self.labels.append(label2)
-                        self.lines.append(line2)
-
-    def reconnect(self):
-        self.cid = self.ax.figure.canvas.mpl_connect('draw_event', self.on_resize)
-        self.update()
-
-    def disconnect(self):
-        if self.labels is not None:
-            for label in self.labels:
-                label.remove()
-        if self.lines is not None:
-            for line in self.lines:
-                line.remove()
-        self.labels = None
-        self.lines = None
-        self.ax.figure.canvas.mpl_disconnect(self.cid)
-
-
-class RegionSelector(object):
-    """
-        Selects fitting region and the regions that are excluded for each edge.
-
-        Select a region with a spanSelector and then type 'a' for all of the fitting region or a number for the edge
-        you want to define the region excluded from the fit (solid state effects).
-
-        see Chapter4 'CH4-Working_with_X-Sections,ipynb' notebook
-
-    """
-
-    def __init__(self, ax):
-        self.ax = ax
-        self.regions = {}
-        self.rect = None
-        self.xmin = 0
-        self.width = 0
-
-        self.span = SpanSelector(ax, self.onselect1, 'horizontal', useblit=True,
-                                 rectprops=dict(alpha=0.5, facecolor='red'), span_stays=True)
-        self.cid = ax.figure.canvas.mpl_connect('key_press_event', self.click)
-        self.draw = ax.figure.canvas.mpl_connect('draw_event', self.on_resize)
-
-    def onselect1(self, xmin, xmax):
-        self.xmin = xmin
-        self.width = xmax - xmin
-
-    def on_resize(self, event):
-        self.update()
-
-    def delete_region(self, key):
-        if key in self.regions:
-            if 'Rect' in self.regions[key]:
-                self.regions[key]['Rect'].remove()
-                self.regions[key]['Text'].remove()
-            del (self.regions[key])
-
-    def update(self):
-
-        y_min, y_max = self.ax.get_ylim()
-        for key in self.regions:
-            if 'Rect' in self.regions[key]:
-                self.regions[key]['Rect'].remove()
-                self.regions[key]['Text'].remove()
-
-            xmin = self.regions[key]['xmin']
-            width = self.regions[key]['width']
-            height = y_max - y_min
-            alpha = self.regions[key]['alpha']
-            color = self.regions[key]['color']
-            self.regions[key]['Rect'] = patches.Rectangle((xmin, y_min), width, height,
-                                                          edgecolor=color, alpha=alpha, facecolor=color)
-            self.ax.add_patch(self.regions[key]['Rect'])
-
-            self.regions[key]['Text'] = self.ax.text(xmin, y_max, self.regions[key]['text'], verticalalignment='top')
-
-    def click(self, event):
-        if str(event.key) in ['1', '2', '3', '4', '5', '6']:
-            key = str(event.key)
-            text = 'exclude \nedge ' + key
-            alpha = 0.5
-            color = 'red'
-        elif str(event.key) in ['a', 'A', 'B', 'b', 'f', 'F']:
-            key = '0'
-            color = 'blue'
-            alpha = 0.2
-            text = 'fit region'
-        else:
-            return
-
-        if key not in self.regions:
-            self.regions[key] = {}
-
-        self.regions[key]['xmin'] = self.xmin
-        self.regions[key]['width'] = self.width
-        self.regions[key]['color'] = color
-        self.regions[key]['alpha'] = alpha
-        self.regions[key]['text'] = text
-
-        self.update()
-
-    def set_regions(self, region, start_x, width):
-        if 'fit' in str(region):
-            key = '0'
-        if region in ['0', '1', '2', '3', '4', '5', '6']:
-            key = region
-        if region in [0, 1, 2, 3, 4, 5, 6]:
-            key = str(region)
-
-        if key not in self.regions:
-            self.regions[key] = {}
-            if key in ['1', '2', '3', '4', '5', '6']:
-                self.regions[key]['text'] = 'exclude \nedge ' + key
-                self.regions[key]['alpha'] = 0.5
-                self.regions[key]['color'] = 'red'
-            elif key == '0':
-                self.regions[key]['text'] = 'fit region'
-                self.regions[key]['alpha'] = 0.2
-                self.regions[key]['color'] = 'blue'
-
-        self.regions[key]['xmin'] = start_x
-        self.regions[key]['width'] = width
-
-        self.update()
-
-    def get_regions(self):
-        tags = {}
-        for key in self.regions:
-            if key == '0':
-                area = 'fit_area'
-            else:
-                area = key
-            tags[area] = {}
-            tags[area]['start_x'] = self.regions[key]['xmin']
-            tags[area]['width_x'] = self.regions[key]['width']
-
-        return tags
-
-    def disconnect(self):
-        for key in self.regions:
-            if 'Rect' in self.regions[key]:
-                self.regions[key]['Rect'].remove()
-                self.regions[key]['Text'].remove()
-        del self.span
-        self.ax.figure.canvas.mpl_disconnect(self.cid)
-        # self.ax.figure.canvas.mpl_disconnect(self.draw)
-        pass
