@@ -1,3 +1,7 @@
+"""
+PeakDialog for interactive_eels
+"""
+
 from PyQt5 import QtCore,  QtWidgets
 
 import numpy as np
@@ -22,7 +26,7 @@ _version = .001
 
 class PeakFitDialog(QtWidgets.QDialog):
     """
-    EELS Input Dialog for Chemical Analysis
+    EELS Input Dialog for Peak-Fit Analysis
     """
 
     def __init__(self, dataset=None):
@@ -34,11 +38,8 @@ class PeakFitDialog(QtWidgets.QDialog):
 
         self.dataset = dataset
         self.energy_scale = np.array([])
-        self.model = np.array([])
-        self.peak_model = np.array([])
         self.peak_out_list = []
         self.p_out = []
-        self.edges = {}
         self.axis = None
         self.show_regions = False
         self.show()
@@ -63,10 +64,8 @@ class PeakFitDialog(QtWidgets.QDialog):
                     self.dataset.metadata['peak_fit']['fit_start'] = \
                         self.dataset.metadata['edges']['fit_area']['fit_start']
                     self.dataset.metadata['peak_fit']['fit_end'] = self.dataset.metadata['edges']['fit_area']['fit_end']
-
                 self.dataset.metadata['peak_fit']['peaks'] = {'0': {'position': self.energy_scale[1],
-                                                                    'amplitude': 1000.0,
-                                                                    'width': 1.0,
+                                                                    'amplitude': 1000.0, 'width': 1.0,
                                                                     'type': 'Gauss', 'asymmetry': 0}}
 
         self.peaks = self.dataset.metadata['peak_fit']
@@ -74,6 +73,18 @@ class PeakFitDialog(QtWidgets.QDialog):
             self.peaks['fit_start'] = self.energy_scale[1]
             self.peaks['fit_end'] = self.energy_scale[-2]
 
+        if 'peak_model' in self.peaks:
+            self.peak_model = self.peaks['peak_model']
+            self.model = self.peak_model
+            if 'edge_model' in self.peaks:
+                self.model = self.model + self.peaks['edge_model']
+        else:
+            self.model = np.array([])
+            self.peak_model = np.array([])
+        if 'peak_out_list' in self.peaks:
+            self.peak_out_list = self.peaks['peak_out_list']
+        self.set_peak_list()
+
         self.update()
         self.dataset.plot()
         if hasattr(self.dataset.view, 'axes'):
@@ -154,8 +165,8 @@ class PeakFitDialog(QtWidgets.QDialog):
         start_channel = np.searchsorted(energy_scale, self.peaks['fit_start'])
         end_channel = np.searchsorted(energy_scale, self.peaks['fit_end'])
 
-        energy_scale = self.dataset.energy_scale[start_channel:end_channel]
-        if self.dataset.energy_scale[0] > 0:
+        energy_scale = self.energy_scale[start_channel:end_channel]
+        if self.energy_scale[0] > 0:
             if 'edges' not in self.dataset.metadata:
                 return
             if 'model' not in self.dataset.metadata['edges']:
@@ -165,40 +176,55 @@ class PeakFitDialog(QtWidgets.QDialog):
         else:
             model = np.zeros(end_channel - start_channel)
 
-        difference = np.array(spectrum - model)
+        difference = np.array(spectrum[start_channel:end_channel] - model)
 
         [self.p_out, _] = scipy.optimize.leastsq(eels.residuals_smooth, np.array(p_in), ftol=1e-3,
                                                  args=(energy_scale, difference, False))
-        self.peak_model = np.zeros(len(self.dataset.energy_scale))
+        self.peak_model = np.zeros(len(self.energy_scale))
         fit = eels.model_smooth(energy_scale, self.p_out, False)
         self.peak_model[start_channel:end_channel] = fit
-        if self.dataset.energy_scale[0] > 0:
+        if self.energy_scale[0] > 0:
             self.model = self.dataset.metadata['edges']['model']['spectrum']
         else:
-            self.model = np.zeros(len(self.dataset.energy_scale))
-        self.model = self.model + self.peak_model
+            self.model = np.zeros(len(self.energy_scale))
 
+        self.dataset.metadata['peak_fit']['edge_model'] = self.model
+        self.model = self.model + self.peak_model
+        self.dataset.metadata['peak_fit']['peak_model'] = self.peak_model
+
+        for key, peak in self.peaks['peaks'].items():
+            if key.isdigit():
+                p_index = int(key)*3
+                self.peaks['peaks'][key] = {'position': self.p_out[p_index],
+                                            'amplitude': self.p_out[p_index+1],
+                                            'width': self.p_out[p_index+2],
+                                            'associated_edge': ''}
+        self.update()
         self.plot()
 
     def smooth(self):
         iterations = int(self.ui.smooth_list.currentIndex())
 
-        # TODO: add sensitivity to dialog and the two funcitons below
+        # TODO: add sensitivity to dialog and the two functions below
         if advanced_present:
             self.peak_model, self.peak_out_list = advanced_eels_tools.smooth(self.dataset,
                                                                              self.peaks['fit_start'],
                                                                              self.peaks['fit_end'],
                                                                              iterations=iterations)
         else:
-            self.peak_model, self.peak_out_list = eels.find_peaks(self.dataset, self.peaks['fit_start'],
-                                                                  self.peaks['fit_end'])
-
+            self.peak_model, peak_out_list = eels.find_peaks(self.dataset, self.peaks['fit_start'],
+                                                             self.peaks['fit_end'])
+            self.peak_out_list = [peak_out_list]
         spec_dim = ft.get_dimensions_by_type('SPECTRAL', self.dataset)[0]
         if spec_dim[1][0] > 0:
             self.model = self.dataset.metadata['edges']['model']['spectrum']
         else:
             self.model = np.zeros(len(spec_dim[1]))
-        self.model = self.model+self.peak_model
+
+        self.dataset.metadata['peak_fit']['edge_model'] = self.model
+        self.model = self.model + self.peak_model
+        self.dataset.metadata['peak_fit']['peak_model'] = self.peak_model
+        self.dataset.metadata['peak_fit']['peak_out_list'] = self.peak_out_list
 
         self.plot()
 
@@ -314,6 +340,20 @@ class PeakFitDialog(QtWidgets.QDialog):
         self.update()
         self.plot()
 
+    def set_peak_list(self):
+        self.ui.peak_list = []
+        if 'peaks' not in self.peaks:
+            self.peaks['peaks'] = {}
+        key = 0
+        for key in self.peaks['peaks']:
+            if key.isdigit():
+                self.ui.peak_list.append(f'Peak {int(key) + 1}')
+        self.ui.find_edit.setText(str(int(key) + 1))
+        self.ui.peak_list.append(f'add peak')
+        self.ui.list3.clear()
+        self.ui.list3.addItems(self.ui.peak_list)
+        self.ui.list3.setCurrentIndex(0)
+
     def on_enter(self):
         if self.sender() == self.ui.edit1:
             value = float(str(self.ui.edit1.displayText()).strip())
@@ -331,9 +371,29 @@ class PeakFitDialog(QtWidgets.QDialog):
                 value = self.energy_scale[-1]
             self.peaks['fit_end'] = value
             self.ui.edit2.setText(str(self.peaks['fit_end']))
+        elif self.sender() == self.ui.edit5:
+            value = float(str(self.ui.edit5.displayText()).strip())
+            peak_index = self.ui.list3.currentIndex()
+            self.peaks['peaks'][str(peak_index)]['position'] = value
+        elif self.sender() == self.ui.edit6:
+            value = float(str(self.ui.edit6.displayText()).strip())
+            peak_index = self.ui.list3.currentIndex()
+            self.peaks['peaks'][str(peak_index)]['amplitude'] = value
+        elif self.sender() == self.ui.edit7:
+            value = float(str(self.ui.edit7.displayText()).strip())
+            peak_index = self.ui.list3.currentIndex()
+            self.peaks['peaks'][str(peak_index)]['width'] = value
 
     def on_list_enter(self):
         # self.setWindowTitle('list')
+        if self.sender() == self.ui.list3:
+            if self.ui.list3.currentText().lower() == 'add peak':
+                peak_index = self.ui.list3.currentIndex()
+                self.ui.list3.insertItem(peak_index, f'Peak {peak_index+1}')
+                self.peaks['peaks'][str(peak_index+1)] = {'position': self.energy_scale[1],
+                                                          'amplitude': 1000.0, 'width': 1.0,
+                                                          'type': 'Gauss', 'asymmetry': 0}
+                self.ui.list3.setCurrentIndex(peak_index)
         self.update()
 
     def set_action(self):
